--
-- MPLogin
--
-- @author  Destroileur
-- Version 1.0
-- @date 20.10.2017

MPLogin = {};
MPLogin.modDir = g_currentModDirectory;

-- character table string
local b='ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/';

-- encoding
function enc(data)
    return ((data:gsub('.', function(x)
        local r,b='',x:byte()
        for i=8,1,-1 do r=r..(b%2^i-b%2^(i-1)>0 and '1' or '0') end
        return r;
    end)..'0000'):gsub('%d%d%d?%d?%d?%d?', function(x)
        if (#x < 6) then return '' end
        local c=0
        for i=1,6 do c=c+(x:sub(i,i)=='1' and 2^(6-i) or 0) end
        return b:sub(c+1,c+1)
    end)..({ '', '==', '=' })[#data%3+1])
end;

function cleanup_string(str)
    str = str:gsub( "%W", "_" );
    str = str:gsub("%d", "_");
	str = str:gsub(",", "");
	str = str:gsub("|", "");
	str = str:gsub("#", "");
    return str;
end;


function MPLogin:fLog(str)

    print(str);

end;

function MPLogin:loadMap(name)

    --print("MPLogin:loadMap");
    
	self.username = "";
	self.inputpassword = "";
	
	self.isConnected = false;
	self.alreadyRegistered = false;
	self.needAdmin = false;
	self.waitReset = false;
	self.currentNeedResetUser = "";
	self.inputSelected = 1;
	self.inputPassword = "";
	self.inputConfirmPassword = "";
	self.inputPasswordShowed = "";
	self.inputConfirmPasswordShowed = "";
	self.saveNeedInputPassword = false;
	self.nbTentative = 0;
	self.lastError = "";
	

	
    self.masterUsername = "";

	self.HUDActive = false;
    self.login_background = createImageOverlay(MPLogin.modDir.."img/"..g_i18n:getText("IMG_BACKGROUND_LOGIN")..".dds");
	self.register_background = createImageOverlay(MPLogin.modDir.."img/"..g_i18n:getText("IMG_BACKGROUND_REGISTER")..".dds");
	self.wait_background = createImageOverlay(MPLogin.modDir.."img/"..g_i18n:getText("IMG_BACKGROUND_WAIT")..".dds");
	self.admin_background = createImageOverlay(MPLogin.modDir.."img/"..g_i18n:getText("IMG_BACKGROUND_ADMIN")..".dds");


	self.filedir = getUserProfileAppPath();
    self.dbfilename = self.filedir.."mplogin_db.xml";
    self.dbFileFound = false;
    getFiles(self.filedir, "getFilesCallback", self);

	self.startTimer = 0;
	self.resetTimer = addTimer(1000, "needReset", self);

end;



function MPLogin:getFilesCallback(filename)
    --print("MPLogin:getFilesCallback");
    if filename == "mplogin_db.xml" then
        self.dbFileFound = true;
		self:fLog("## MPLogin ## Database file found");
    end;
end;

function MPLogin:createDataFile()
    --print("MPLogin:createDataFile");
    local xml = createXMLFile("mplogin_db", self.dbfilename, "mplogin_db");
    saveXMLFile(xml);
    delete(xml);
    self.dbFileFound = true;
end;

function MPLogin:getUsername()
    --print("MPLogin:getUsername");
    for a=1, table.getn(g_currentMission.users) do
        local user = g_currentMission.users[a];
        if user.userId == g_currentMission.playerUserId then
            self.username = user.nickname;
			self.username = cleanup_string(self.username);
            break;
        end;
    end;
end;

function MPLogin:update(dt)

	if (self.startTimer == 0 and g_gui.currentGui == nil and self.HUDActive == false and self.isConnected == false) then
		self.startTimer = addTimer(1000, "enterMenu", self);
	end;

	if (self.HUDActive) then 
		InputBinding.setShowMouseCursor(true);
		if not (g_gui.currentGui == self) then
			self.HUDActive = false;
			self:enterMenu();
		end;
	end;
	

end;

function MPLogin:enterMenu()

    if (self.HUDActive == false) then
		self.HUDActive = true;
        if self.username == "" then
            MPLogin:getUsername();
        end;
        if g_currentMission:getIsServer() then
            self.masterUsername = self.username;
        end;
        InputBinding.setShowMouseCursor(true);
        g_gui.currentGui = self;
		self:isRegistered();
    end;

end;

function MPLogin:leaveMenu()

    --print("MPLogin:leaveMenu");
    if (self.HUDActive) then
        self.HUDActive = false;
        InputBinding.setShowMouseCursor(false);
        g_gui.currentGui = nil;
    end;
	
end;

function MPLogin:draw()

    if self.HUDActive then

		if (self.alreadyRegistered) then
		
			if (self.needAdmin) then
				
				renderOverlay(self.admin_background, 0, 0, 1, 1);
				
				--local fontSize = 0.070;
				--setTextColor(1, 1, 1, 1);
				--renderText(0.3760, 0.7331, fontSize, g_i18n:getText("ADMIN_TITLE"));
				
				--local fontSize = 0.060;
				--renderText(0.4272, 0.2346, fontSize, g_i18n:getText("ADMIN_BUT_ALLOW"));
				
				--local fontSize = 0.035;
				--renderText(0.4067, 0.3205, fontSize, g_i18n:getText("ADMIN_BUT_REFUSE"));
				--renderText(0.5385, 0.3205, fontSize, g_i18n:getText("ADMIN_BUT_EJECT"));
				
				--local fontSize = 0.030;
				--renderText(0.3827, 0.6441, fontSize, g_i18n:getText("ADMIN_WARNING_1"));
				--renderText(0.3827, 0.6031, fontSize, g_i18n:getText("ADMIN_WARNING_2"));
				--renderText(0.3827, 0.5620, fontSize, g_i18n:getText("ADMIN_WARNING_3"));
				
				--local fontSize = 0.034;
				--renderText(0.3828, 0.4711, fontSize, g_i18n:getText("ADMIN_USERNAME"));
				
				local fontSize = 0.036;
				setTextColor(0, 1, 1, 1);
				renderText(0.3935, 0.4095, fontSize, self.currentNeedResetUser);
			
			elseif (self.waitReset) then
			
				renderOverlay(self.wait_background, 0, 0, 1, 1);
				
				-- local fontSize = 0.070;
				-- setTextColor(1, 1, 1, 1);
				-- renderText(0.3847, 0.6070, fontSize, g_i18n:getText("WAIT_TITLE"));
				
				-- local fontSize = 0.060;
				-- renderText(0.4023, 0.3519, fontSize, g_i18n:getText("WAIT_BUT_CANCEL"));
				
				-- local fontSize = 0.030;
				-- renderText(0.3833, 0.5210, fontSize, g_i18n:getText("WAIT_WARNING_1"));
				-- renderText(0.3833, 0.4799, fontSize, g_i18n:getText("WAIT_WARNING_2"));
				
			else
			
				renderOverlay(self.login_background, 0, 0, 1, 1);
			
				-- local fontSize = 0.070;
				-- setTextColor(1, 1, 1, 1);
				-- renderText(0.1894, 0.6862, fontSize, g_i18n:getText("LOGIN_TITLE"));
				-- renderText(0.5579, 0.2336, fontSize, g_i18n:getText("LOGIN_BUT_CONNECTION"));
				
				-- local fontSize = 0.035;
				-- renderText(0.1425, 0.1944, fontSize, g_i18n:getText("BUT_QUIT"));
				-- renderText(0.2700, 0.1944, fontSize, g_i18n:getText("LOGIN_RESET_PASSWORD"));
				
				-- local fontSize = 0.034;
				-- renderText(0.4926, 0.7163, fontSize, g_i18n:getText("USER_LOGIN"));
				-- renderText(0.4926, 0.5648, fontSize, g_i18n:getText("LOGIN_PASSWORD"));
				-- renderText(0.5620, 0.3978, fontSize, g_i18n:getText("LOGIN_SAVE_PASSWORD"));
				
				-- local fontSize = 0.030;
				-- renderText(0.1474, 0.5855, fontSize, g_i18n:getText("LOGIN_WARNING_1"));
				-- renderText(0.1474, 0.5444, fontSize, g_i18n:getText("LOGIN_WARNING_2"));
				-- renderText(0.1474, 0.5034, fontSize, g_i18n:getText("LOGIN_WARNING_3"));
				
				local fontSize = 0.036;
				setTextColor(0, 1, 1, 1);
				renderText(0.5170, 0.6500, fontSize, self.username);
				
				setTextColor(1, 1, 1, 1);
				
				if (self.inputSelected == 1) then
					renderText(0.5170, 0.4985, fontSize, self.inputPasswordShowed.."_");
				else
					renderText(0.5170, 0.4985, fontSize, self.inputPasswordShowed);
				end;
				
				if (self.saveNeedInputPassword) then
					renderText(0.5171, 0.3890, 0.05, "X");
				end;
			
			end;
		
		else
			
			renderOverlay(self.register_background, 0, 0, 1, 1);
			
			-- local fontSize = 0.070;
			-- setTextColor(1, 1, 1, 1);
			-- renderText(0.1909, 0.7057, fontSize, g_i18n:getText("REGISTER_TITLE"));
			-- renderText(0.5493, 0.2306, fontSize, g_i18n:getText("REGISTER_BUT_REGISTER"));
			
			-- local fontSize = 0.035;
			-- renderText(0.1386, 0.1964, fontSize, g_i18n:getText("BUT_QUIT"));
			
			-- local fontSize = 0.034;
			-- renderText(0.4926, 0.7162, fontSize, g_i18n:getText("USER_LOGIN"));
			-- renderText(0.4926, 0.5784, fontSize, g_i18n:getText("REGISTER_PASSWORD"));
			-- renderText(0.4926, 0.4386, fontSize, g_i18n:getText("REGISTER_CONFIRM_PASSWORD"));
			
			-- local fontSize = 0.030;
			-- renderText(0.1513, 0.6129, fontSize, g_i18n:getText("REGISTER_WARNING_1"));
			-- renderText(0.1513, 0.5689, fontSize, g_i18n:getText("REGISTER_WARNING_2"));
			-- renderText(0.1513, 0.5268, fontSize, g_i18n:getText("REGISTER_WARNING_3"));
			
			local fontSize = 0.036;
			setTextColor(0, 1, 1, 1);
			renderText(0.5170, 0.6529, fontSize, self.username);
			
			setTextColor(1, 1, 1, 1);
			if (self.inputSelected == 1) then
				renderText(0.5170, 0.5122, fontSize, self.inputPasswordShowed.."_");
				renderText(0.5170, 0.3724, fontSize, self.inputConfirmPasswordShowed);
			elseif (self.inputSelected == 2) then
				renderText(0.5170, 0.5122, fontSize, self.inputPasswordShowed);
				renderText(0.5170, 0.3724, fontSize, self.inputConfirmPasswordShowed.."_");
			else
				renderText(0.5170, 0.5122, fontSize, self.inputPasswordShowed);
				renderText(0.5170, 0.3724, fontSize, self.inputConfirmPasswordShowed);
			end;
			
		end;
		
		local fontSize = 0.036;
		setTextColor(1, 0, 0, 1);
		renderText(0.1513, 0.2805, fontSize, self.lastError);

    end;

end;

function MPLogin:mouseEvent(posX, posY, isDown, isUp, button)

	-- if (isDown or isDown) then
		-- if (g_gui.currentGui == nil and self.HUDActive == false and self.isConnected == false) then
			-- self.startTimer = addTimer(1000, "enterMenu", self);
		-- end;
	-- end;

    if self.HUDActive then
        if isUp then
		
			if (self.alreadyRegistered) then
			
				if (self.needAdmin) then
				
					-- but refuse
					if posX > 0.3818 and posX < 0.5097 and posY > 0.3098 and posY < 0.3607 then
						self:refuse(self.currentNeedResetUser);
					end;
					
					-- but eject
					if posX > 0.5195 and posX < 0.6474 and posY > 0.3098 and posY < 0.3607 then
						self:eject(self.currentNeedResetUser);
					end;
					
					-- but allow
					if posX > 0.3818 and posX < 0.6474 and posY > 0.2228 and posY < 0.2932 then
						self:allow(self.currentNeedResetUser);
					end;
				
				elseif (self.waitReset) then
				
					-- but cancel reset
					if posX > 0.3256 and posX < 0.6445 and posY > 0.3274 and posY < 0.7585 then
						self.waitReset = false;
					end;
					
				else
			
					-- select input password
					if posX > 0.5107 and posX < 0.8364 and posY > 0.4838 and posY < 0.5415 then
						self.inputSelected = 1;
						self.inputPasswordShowed = self.inputPasswordShowed;
					end;
					
					-- toggle save password
					if posX > 0.5097 and posX < 0.5415 and posY > 0.3773 and posY < 0.4340 then
						if (self.saveNeedInputPassword == true) then
							self.saveNeedInputPassword = false
						else
							self.saveNeedInputPassword = true
						end;
					end;
					
					-- but login
					if posX > 0.4780 and posX < 0.8598 and posY > 0.2023 and posY < 0.3157 then
						self:login();
					end;
					
					-- but exit
					if posX > 0.1337 and posX < 0.2382 and posY > 0.1818 and posY < 0.2326 then
						requestExit();
					end;
					
					-- but lostPassword
					if posX > 0.2534 and posX < 0.4677 and posY > 0.1808 and posY < 0.2336 then
						self.waitReset = true;
						self.lastError = "";
					end;
				
				
				end;
			
			else

				-- select input password
				if posX > 0.5097 and posX < 0.8374 and posY > 0.4956 and posY < 0.5513 then
					self.inputSelected = 1;
				end;
				
				-- select input confirm password
				if posX > 0.5097 and posX < 0.8374 and posY > 0.3577 and posY < 0.4134 then
					self.inputSelected = 2;
				end;
				
				-- but register
				if posX > 0.4770 and posX < 0.8608 and posY > 0.1964 and posY < 0.3108 then
					self:registration();
				end;
				
				-- but exit
				if posX > 0.1337 and posX < 0.2382 and posY > 0.1818 and posY < 0.2326 then
					requestExit();
				end;
				
			end;

        end;
    end;
	
end;

function MPLogin:isRegistered()

	if g_currentMission:getIsServer() then
		self:ServerController(self.username, "isRegistered", "");
	else
		ServerControllerEvent.sendEvent(self.username, "isRegistered", "");
	end;

end;


function MPLogin:refuse(username)

	if (username == self.username) then
		self:ClientController(username, "refuse");
	else
		if g_currentMission:getIsServer() then
			ClientControllerEvent.sendEvent(username, "refuse", "");
		else
			ServerControllerEvent.sendEvent(self.username, "refuse", username);
		end
	end;
	
	self:endReset(username);

end;

function MPLogin:eject(username)

	if (username == self.username) then
		self:ClientController(username, "eject");
	else
		if g_currentMission:getIsServer() then
			ClientControllerEvent.sendEvent(username, "eject", "");
		else
			ServerControllerEvent.sendEvent(self.username, "eject", username);
		end
	end
	
	self:endReset(username);

end;

function MPLogin:allow(username)

	if (username == self.username) then
		self:ClientController(username, "allow");
	else
		if g_currentMission:getIsServer() then
			ClientControllerEvent.sendEvent(username, "allow", "");
		else
			ServerControllerEvent.sendEvent(self.username, "allow", username);
		end
	end
	
	self:endReset(username);
	
end;

function MPLogin:needReset()

	if (self.waitReset) then
		if g_currentMission:getIsServer() then
			self:ServerController(self.username, "needReset", "");
		else
			ServerControllerEvent.sendEvent(self.username, "needReset", "");
		end
	end;
	
	return true;

end;

function MPLogin:endReset(username)

	if g_currentMission:getIsServer() then
		self:ServerController(self.username, "endReset", username);
	else
		ServerControllerEvent.sendEvent(self.username, "endReset", username);
	end

	if (self.isConnected) then
		self:leaveMenu();
	end;
	self.needAdmin = false;

end;

function MPLogin:registration()

	if (string.len(self.inputPassword)>= 4) then
		if (self.inputPassword == self.inputConfirmPassword) then
			if g_currentMission:getIsServer() then
				self:ServerController(self.username, "registration", enc(self.inputPassword));
			else
				ServerControllerEvent.sendEvent(self.username, "registration", enc(self.inputPassword));
			end
		else
			-- Not same confirm password
			self.lastError = g_i18n:getText("NOT_SAME_PASSWORD");
		end;
	else
		-- Password too short
		self.lastError = g_i18n:getText("PASSWORD_TOO_SHORT");
	end;
	
end;

function MPLogin:login()

	if (string.len(self.inputPassword)>= 4) then
		if g_currentMission:getIsServer() then
			self:ServerController(self.username, "login", enc(self.inputPassword));
		else
			ServerControllerEvent.sendEvent(self.username, "login", enc(self.inputPassword));
		end
	else
		self.lastError = g_i18n:getText("PASSWORD_TOO_SHORT");
	end;
	
end;

function MPLogin:isMaster(username)
	if not (username == "") then
		if g_currentMission:getIsServer() then
			self.masterUsername = self.username;
		end;
		if (username == self.masterUsername) then
			return true;
		end;
		for a=1, table.getn(g_currentMission.users) do
			if g_currentMission.users[a].nickname == username then
				if g_currentMission.users[a].isMasterUser then
					self.masterUsername = username;
					return true;
				end;
			end;
		end;
	end;
    return false;
end;

function MPLogin:saveInputPassword()
	if not self.dbFileFound then
        self:createDataFile();
    end;
	local xml = loadXMLFile("mplogin_db", self.dbfilename);
	setXMLString(xml, "mplogin_db.savedInputPassword", self.inputPassword);
	saveXMLFile(xml);
	delete(xml);
end;

function MPLogin:loadInputPassword()
	if not self.dbFileFound then
        self:createDataFile();
    end;
    local xml = loadXMLFile("mplogin_db", self.dbfilename);
	self.inputPassword = Utils.getNoNil(getXMLString(xml, "mplogin_db.savedInputPassword"), "");
	self.inputPasswordShowed = self:transformStars(self.inputPassword);
	delete(xml);
end;

function MPLogin:getPassword(xml, username)
    --print("MPLogin:getPassword");
    local clean_username = cleanup_string(tostring(username));
    local password = Utils.getNoNil(getXMLString(xml, "mplogin_db."..tostring(clean_username)), "");
    return password;
end;

function MPLogin:setPassword(xml, username, password)
    --print("MPLogin:setPassword");
    local clean_username = cleanup_string(tostring(username));
    setXMLString(xml, "mplogin_db."..tostring(clean_username), password);
    saveXMLFile(xml);
end;



function MPLogin:SendToClient(actionTarget, actionType, actionData)

	if g_currentMission:getIsServer() then
		if (actionTarget == self.username) then
			self:ClientController(actionTarget, actionType, actionData);
		else
			ClientControllerEvent.sendEvent(actionTarget, actionType, actionData);
		end;
	else
		self:fLog("## MPLogin ## ERROR : Can not send client to client !");
	end;

end;

function MPLogin:SendToServer(actionSender, actionType, actionData)

	if g_currentMission:getIsServer() then
		self:ServerController(actionSender, actionType, actionData);
	else
		ServerControllerEvent.sendEvent(actionSender, actionType, actionData);
	end

end;


function MPLogin:ClientController(actionTarget, actionType, actionData)
	
	
	if (actionTarget == self.username or actionTarget == "%all") then
		if actionType == "isRegistered" then
			if (actionData == "true") then
				self.alreadyRegistered = true;
				self:loadInputPassword();
			else
				self.alreadyRegistered = false;
			end;
		elseif actionType == "registration" then
			if (actionData == "true") then
				self.alreadyRegistered = true;
				self.lastError = "";
			else
				self.lastError = g_i18n:getText("CAN_NOT_REGISTER");
			end;
		elseif actionType == "login" then
			if (actionData == "true") then
				if (self.saveNeedInputPassword) then
					self:saveInputPassword();
				end;
				self.isConnected = true;
				self.lastError = "";
				self.nbTentative = 0;
				self:leaveMenu();
				removeTimer(self.resetTimer);
			else
				self.nbTentative = self.nbTentative + 1;
				if (self.nbTentative >= 5) then
					requestExit();
				end;
				self.lastError = tostring(5-self.nbTentative) .. " " .. g_i18n:getText("NUMBER_TENTIVE");
			end;
		elseif actionType == "refuse" then
			self.waitReset = false;
			self.lastError = g_i18n:getText("RESET_REFUSE");
		elseif actionType == "eject" then
			self.waitReset = false;
			requestExit();
		elseif actionType == "allow" then
			self.waitReset = false;
			self.alreadyRegistered = false;
			self.inputPassword = "";
			self.inputConfirmPassword = "";
			self.inputPasswordShowed = "";
			self.inputConfirmPasswordShowed = "";
			self.lastError = "";
		elseif actionType == "needReset" then
			if (g_gui.currentGui == nil) then
				if (self.needAdmin == false) then
					self.needAdmin = true;
					self:enterMenu();
					self.currentNeedResetUser = actionData;
				end;
			end;
		elseif actionType == "endReset" then
			if (self.currentNeedResetUser == actionData) then
				if (self.isConnected) then
					self:leaveMenu();
				end;
				self.needAdmin = false;
			end;
		else
			self:fLog("## MPLogin ## ERROR : Invalid action '"..actionType.."' from server");
		end;
	end;
	
end;

function MPLogin:ServerController(actionSender, actionType, actionData)

	
	if not self.dbFileFound then
        self:createDataFile();
        self:fLog("## MPLogin ## Create new database file");
    end;
	
	-- Get data file
    local xml = loadXMLFile("mplogin_db", self.dbfilename);

	if actionType == "isRegistered" then
		local senderPassword = self:getPassword(xml, actionSender);
		local reponseString = "false"
		if (string.len(senderPassword) > 0) then
			reponseString = "true";
		end;
		if (self:isMaster(actionSender)) then
			self:ClientController(actionSender, "isRegistered", reponseString);
		else
			ClientControllerEvent.sendEvent(actionSender, "isRegistered", reponseString);
		end;
    elseif actionType == "registration" then
		self:setPassword(xml, actionSender, actionData);
		if (self:isMaster(actionSender)) then
			self:ClientController(actionSender, "registration", "true");
		else
			ClientControllerEvent.sendEvent(actionSender, "registration", "true");
		end;
	elseif actionType == "login" then
		local senderPassword = self:getPassword(xml, actionSender);
		local reponseString = "false"
		if (senderPassword == actionData) then
			reponseString = "true";
		end;
		if (self:isMaster(actionSender)) then
			self:ClientController(actionSender, "login", reponseString);
		else
			ClientControllerEvent.sendEvent(actionSender, "login", reponseString);
		end;
	elseif actionType == "needReset" then
		if (g_gui.currentGui == nil or actionSender == self.username) then
			if (self.needAdmin == false) then
				self.needAdmin = true;
				self:enterMenu();
				self.currentNeedResetUser = actionSender;
			end;
		end;
		for a=1, table.getn(g_currentMission.users) do
			if not (g_currentMission.users[a].nickname == self.username) then
				if g_currentMission.users[a].isMasterUser then
					ClientControllerEvent.sendEvent(g_currentMission.users[a].nickname, "needReset", actionSender);
				end;
			end;
		end;
	elseif actionType == "refuse" then
		if (actionData == self.username) then
			self:ClientControllerEvent(actionData, "refuse", actionData);
		else
			ClientControllerEvent.sendEvent(actionData, "refuse", "");
		end;
	elseif actionType == "eject" then
		if (actionData == self.username) then
			self:ClientControllerEvent(actionData, "eject");
		else
			ClientControllerEvent.sendEvent(actionData, "eject", "");
		end;
	elseif actionType == "allow" then
		if (actionData == self.username) then
			self:ClientControllerEvent(actionData, "allow");
		else
			ClientControllerEvent.sendEvent(actionData, "allow", "");
		end;
	elseif actionType == "endReset" then
		if (self.currentNeedResetUser == actionData) then
			if (self.isConnected) then
				self:leaveMenu();
			end;
			self.needAdmin = false;
		end;
		ClientControllerEvent.sendEvent("%all", "endReset", actionData);
    else
		self:fLog("## MPLogin ## ERROR : Invalid action '"..actionType.."' from "..actionSender);
    end;
	
	-- Close data file
    delete(xml);
	
end;

function MPLogin:getKeyString(sym)

	if sym == Input.KEY_0 then
		return ("0");
	end;
	if sym == Input.KEY_1 then
		return ("1");
	end;
	if sym == Input.KEY_2 then
		return ("2");
	end;
	if sym == Input.KEY_3 then
		return ("3");
	end;
	if sym == Input.KEY_4 then
		return ("4");
	end;
	if sym == Input.KEY_5 then
		return ("5");
	end;
	if sym == Input.KEY_6 then
		return ("6");
	end;
	if sym == Input.KEY_7 then
		return ("7");
	end;
	if sym == Input.KEY_8 then
		return ("8");
	end;
	if sym == Input.KEY_9 then
		return ("9");
	end;
	
	if sym == Input.KEY_KP_0 then
		return ("0");
	end;
	if sym == Input.KEY_KP_1 then
		return ("1");
	end;
	if sym == Input.KEY_KP_2 then
		return ("2");
	end;
	if sym == Input.KEY_KP_3 then
		return ("3");
	end;
	if sym == Input.KEY_KP_4 then
		return ("4");
	end;
	if sym == Input.KEY_KP_5 then
		return ("5");
	end;
	if sym == Input.KEY_KP_6 then
		return ("6");
	end;
	if sym == Input.KEY_KP_7 then
		return ("7");
	end;
	if sym == Input.KEY_KP_8 then
		return ("8");
	end;
	if sym == Input.KEY_KP_9 then
		return ("9");
	end;
	
	return "";
	
end;

function MPLogin:transformStars(str)
	local starsLen = string.len(str);
	local stars = "";
	for i=1,starsLen do
      stars = stars .. "x";
    end
	return stars;
end;

function MPLogin:keyEvent(unicode, sym, modifier, isDown)

	if isDown then
		if self.HUDActive then
			if (self.inputSelected == 1) then
				if sym == Input.KEY_backspace then
					self.inputPassword = string.sub (self.inputPassword, 0, string.len(self.inputPassword)-1);
					self.inputPasswordShowed = self:transformStars(self.inputPassword);
				else
					local inputChar = self:getKeyString(sym);
					if not (inputChar == "") then
						self.inputPasswordShowed = self:transformStars(self.inputPassword) .. inputChar;
						self.inputPassword = self.inputPassword .. inputChar;
					end;
				end;
			end;
			if (self.inputSelected == 2) then
				if sym == Input.KEY_backspace then
					self.inputConfirmPassword = string.sub (self.inputConfirmPassword, 0, string.len(self.inputConfirmPassword)-1);
					self.inputConfirmPasswordShowed = self:transformStars(self.inputConfirmPassword);
				else
					local inputChar = self:getKeyString(sym);
					if not (inputChar == "") then
						self.inputConfirmPasswordShowed = self:transformStars(self.inputConfirmPassword) .. inputChar;
						self.inputConfirmPassword = self.inputConfirmPassword .. inputChar;
					end;
				end;
			end;
			if sym == Input.KEY_return or sym == Input.KEY_KP_enter then
				if self.alreadyRegistered then
					self:login();
				else
					self:registration();
				end;
			end;
		end;
	end;
	
	-- if (g_gui.currentGui == nil and self.HUDActive == false and self.isConnected == false) then
		-- self.startTimer = addTimer(1000, "enterMenu", self);
	-- end;
	

end;

addModEventListener(MPLogin);

function MPLogin:deleteMap()
end;